var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
import hash from "@emotion/hash";
import { inject, computed, unref, defineComponent, provide, shallowRef, ref, watch, onBeforeUnmount, createVNode, mergeProps, Fragment } from "vue";
import unitless from "@emotion/unitless";
import { serialize, compile, stringify } from "stylis";
class Entity {
  constructor(instanceId) {
    __publicField(this, "instanceId");
    /** @private Internal cache map. Do not access this directly */
    __publicField(this, "cache", /* @__PURE__ */ new Map());
    this.instanceId = instanceId;
  }
  get(keys) {
    return this.cache.get(keys.join("%")) || null;
  }
  update(keys, valueFn) {
    const path = keys.join("%");
    const prevValue = this.cache.get(path);
    const nextValue = valueFn(prevValue);
    if (nextValue === null)
      this.cache.delete(path);
    else
      this.cache.set(path, nextValue);
  }
}
const ATTR_TOKEN = "data-token-hash";
const ATTR_MARK = "data-css-hash";
const ATTR_DEV_CACHE_PATH = "data-dev-cache-path";
const CSS_IN_JS_INSTANCE = "__cssinjs_instance__";
function createCache() {
  const cssinjsInstanceId = Math.random().toString(12).slice(2);
  if (typeof document !== "undefined" && document.head && document.body) {
    const styles = document.body.querySelectorAll(`style[${ATTR_MARK}]`) || [];
    const {
      firstChild
    } = document.head;
    Array.from(styles).forEach((style) => {
      style[CSS_IN_JS_INSTANCE] = style[CSS_IN_JS_INSTANCE] || cssinjsInstanceId;
      document.head.insertBefore(style, firstChild);
    });
    const styleHash = {};
    Array.from(document.querySelectorAll(`style[${ATTR_MARK}]`)).forEach((style) => {
      var _a;
      const hash2 = style.getAttribute(ATTR_MARK);
      if (styleHash[hash2]) {
        if (style[CSS_IN_JS_INSTANCE] === cssinjsInstanceId)
          (_a = style.parentNode) == null ? void 0 : _a.removeChild(style);
      } else {
        styleHash[hash2] = true;
      }
    });
  }
  return new Entity(cssinjsInstanceId);
}
const StyleContextKey = Symbol("StyleContextKey");
const cache = createCache();
const useStyleInject = () => {
  return inject(StyleContextKey, {
    hashPriority: "low",
    cache,
    defaultCache: true
  });
};
const useStyleProvider = (props) => {
  const parentContext = useStyleInject();
  const context = computed(() => {
    const mergedContext = {
      ...parentContext
    };
    const propsValue = unref(props);
    Object.keys(propsValue).forEach((key) => {
      const value = propsValue[key];
      if (propsValue[key] !== void 0)
        mergedContext[key] = value;
    });
    const {
      cache: cache2
    } = propsValue;
    mergedContext.cache = mergedContext.cache || createCache();
    mergedContext.defaultCache = !cache2 && parentContext.defaultCache;
    return mergedContext;
  });
  return context;
};
const StyleProvider = /* @__PURE__ */ defineComponent({
  name: "StyleProvider",
  props: {
    autoClear: Boolean,
    mock: String,
    cache: {
      type: Object,
      default: () => createCache()
    },
    hashPriority: {
      type: String,
      default: "low"
    },
    container: Object,
    ssrInline: Boolean,
    transformers: Array,
    linters: Array,
    defaultCache: {
      type: Boolean,
      default: true
    }
  },
  setup(props, ctx) {
    provide(StyleContextKey, props);
    return () => {
      var _a, _b;
      return (_b = (_a = ctx.slots).default) == null ? void 0 : _b.call(_a);
    };
  }
});
function canUseDom() {
  return !!(typeof window !== "undefined" && window.document && window.document.createElement);
}
function contains(root, n) {
  if (!root)
    return false;
  if (root.contains)
    return root.contains(n);
  let node = n;
  while (node) {
    if (node === root)
      return true;
    node = node.parentNode;
  }
  return false;
}
const APPEND_ORDER = "data-rc-order";
const MARK_KEY = "rc-util-key";
const containerCache = /* @__PURE__ */ new Map();
function getMark({ mark } = {}) {
  if (mark)
    return mark.startsWith("data-") ? mark : `data-${mark}`;
  return MARK_KEY;
}
function getContainer(option) {
  if (option.attachTo)
    return option.attachTo;
  const head = document.querySelector("head");
  return head || document.body;
}
function getOrder(prepend) {
  if (prepend === "queue")
    return "prependQueue";
  return prepend ? "prepend" : "append";
}
function findStyles(container) {
  return Array.from(
    (containerCache.get(container) || container).children
  ).filter((node) => node.tagName === "STYLE");
}
function injectCSS(css, option = {}) {
  if (!canUseDom())
    return null;
  const { csp, prepend } = option;
  const styleNode = document.createElement("style");
  styleNode.setAttribute(APPEND_ORDER, getOrder(prepend));
  if (csp == null ? void 0 : csp.nonce)
    styleNode.nonce = csp == null ? void 0 : csp.nonce;
  styleNode.innerHTML = css;
  const container = getContainer(option);
  const { firstChild } = container;
  if (prepend) {
    if (prepend === "queue") {
      const existStyle = findStyles(container).filter(
        (node) => ["prepend", "prependQueue"].includes(node.getAttribute(APPEND_ORDER))
      );
      if (existStyle.length) {
        container.insertBefore(
          styleNode,
          existStyle[existStyle.length - 1].nextSibling
        );
        return styleNode;
      }
    }
    container.insertBefore(styleNode, firstChild);
  } else {
    container.appendChild(styleNode);
  }
  return styleNode;
}
function findExistNode(key, option = {}) {
  const container = getContainer(option);
  return findStyles(container).find(
    (node) => node.getAttribute(getMark(option)) === key
  );
}
function removeCSS(key, option = {}) {
  const existNode = findExistNode(key, option);
  if (existNode) {
    const container = getContainer(option);
    container.removeChild(existNode);
  }
}
function syncRealContainer(container, option) {
  const cachedRealContainer = containerCache.get(container);
  if (!cachedRealContainer || !contains(document, cachedRealContainer)) {
    const placeholderStyle = injectCSS("", option);
    const { parentNode } = placeholderStyle;
    containerCache.set(container, parentNode);
    container.removeChild(placeholderStyle);
  }
}
function updateCSS(css, key, option = {}) {
  var _a, _b, _c;
  const container = getContainer(option);
  syncRealContainer(container, option);
  const existNode = findExistNode(key, option);
  if (existNode) {
    if (((_a = option.csp) == null ? void 0 : _a.nonce) && existNode.nonce !== ((_b = option.csp) == null ? void 0 : _b.nonce))
      existNode.nonce = (_c = option.csp) == null ? void 0 : _c.nonce;
    if (existNode.innerHTML !== css)
      existNode.innerHTML = css;
    return existNode;
  }
  const newNode = injectCSS(css, option);
  newNode.setAttribute(getMark(option), key);
  return newNode;
}
function flattenToken(token) {
  let str = "";
  Object.keys(token).forEach((key) => {
    const value = token[key];
    str += key;
    if (value && typeof value === "object")
      str += flattenToken(value);
    else
      str += value;
  });
  return str;
}
function token2key(token, salt) {
  return hash(`${salt}_${flattenToken(token)}`);
}
const layerKey = `layer-${Date.now()}-${Math.random()}`.replace(/\./g, "");
const layerWidth = "903px";
function supportSelector(styleStr, handleElement) {
  var _a;
  if (canUseDom()) {
    updateCSS(styleStr, layerKey);
    const ele = document.createElement("div");
    ele.style.position = "fixed";
    ele.style.left = "0";
    ele.style.top = "0";
    handleElement == null ? void 0 : handleElement(ele);
    document.body.appendChild(ele);
    if (process.env.NODE_ENV !== "production") {
      ele.innerHTML = "Test";
      ele.style.zIndex = "9999999";
    }
    const support = getComputedStyle(ele).width === layerWidth;
    (_a = ele.parentNode) == null ? void 0 : _a.removeChild(ele);
    removeCSS(layerKey);
    return support;
  }
  return false;
}
let canLayer;
function supportLayer() {
  if (canLayer === void 0) {
    canLayer = supportSelector(
      `@layer ${layerKey} { .${layerKey} { width: ${layerWidth}!important; } }`,
      (ele) => {
        ele.className = layerKey;
      }
    );
  }
  return canLayer;
}
function useProdHMR() {
  return false;
}
let webpackHMR = false;
let viteHMR = false;
function useDevHMR() {
  return webpackHMR || viteHMR;
}
const useHMR = process.env.NODE_ENV === "production" ? useProdHMR : useDevHMR;
if (process.env.NODE_ENV !== "production" && (typeof module !== "undefined" && module && // @ts-ignore
module.hot || // @ts-ignore
false)) {
  const win = window;
  if (typeof win.webpackHotUpdate === "function") {
    const originWebpackHotUpdate = win.webpackHotUpdate;
    win.webpackHotUpdate = (...args) => {
      webpackHMR = true;
      setTimeout(() => {
        webpackHMR = false;
      }, 0);
      return originWebpackHotUpdate(...args);
    };
  }
}
function useClientCache(prefix, keyPath, cacheFn, onCacheRemove) {
  const styleContext = useStyleInject();
  const fullPathStr = shallowRef("");
  const fullPath = computed(() => {
    return [prefix, ...keyPath.value];
  });
  const cachePath = ref([...fullPath.value]);
  const clearCache = (paths) => {
    styleContext.cache.update(paths, (prevCache) => {
      const [times = 0, cache2] = prevCache || [];
      const nextCount = times - 1;
      if (nextCount === 0) {
        onCacheRemove == null ? void 0 : onCacheRemove(cache2, false);
        return null;
      }
      return [times - 1, cache2];
    });
  };
  watch(() => fullPath.value.slice(), (newVal, oldValue) => {
    clearCache(oldValue);
    cachePath.value = newVal;
    fullPathStr.value = newVal.join("-");
  });
  const HMRUpdate = useHMR();
  const flush = () => {
    styleContext.cache.update(fullPath.value, (prevCache) => {
      const [times = 0, cache2] = prevCache || [];
      let tmpCache = cache2;
      if (process.env.NODE_ENV !== "production" && cache2 && HMRUpdate) {
        onCacheRemove == null ? void 0 : onCacheRemove(tmpCache, HMRUpdate);
        tmpCache = null;
      }
      const mergedCache = tmpCache || cacheFn();
      return [times + 1, mergedCache];
    });
  };
  watch(fullPathStr, () => {
    flush();
  }, {
    immediate: true
  });
  onBeforeUnmount(() => {
    clearCache(fullPath.value);
  });
  return computed(() => {
    const cache2 = styleContext.cache.get(cachePath.value);
    return cache2[1];
  });
}
const EMPTY_OVERRIDE = {};
const hashPrefix = process.env.NODE_ENV !== "production" ? "css-dev-only-do-not-override" : "css";
const tokenKeys = /* @__PURE__ */ new Map();
function recordCleanToken(tokenKey) {
  tokenKeys.set(tokenKey, (tokenKeys.get(tokenKey) || 0) + 1);
}
function removeStyleTags(key, instanceId) {
  if (typeof document !== "undefined") {
    const styles = document.querySelectorAll(`style[${ATTR_TOKEN}="${key}"]`);
    styles.forEach((style) => {
      var _a;
      if (style[CSS_IN_JS_INSTANCE] === instanceId)
        (_a = style.parentNode) == null ? void 0 : _a.removeChild(style);
    });
  }
}
function cleanTokenStyle(tokenKey, instanceId) {
  tokenKeys.set(tokenKey, (tokenKeys.get(tokenKey) || 0) - 1);
  const tokenKeyList = Array.from(tokenKeys.keys());
  const cleanableKeyList = tokenKeyList.filter((key) => {
    const count = tokenKeys.get(key) || 0;
    return count <= 0;
  });
  if (cleanableKeyList.length < tokenKeyList.length) {
    cleanableKeyList.forEach((key) => {
      removeStyleTags(key, instanceId);
      tokenKeys.delete(key);
    });
  }
}
function useCacheToken(theme, tokens, option = ref({})) {
  const contextProps = useStyleInject();
  const mergedToken = computed(() => {
    return Object.assign({}, ...tokens.value);
  });
  const tokenStr = computed(() => {
    return flattenToken(mergedToken.value);
  });
  const overrideTokenStr = computed(() => {
    return flattenToken(option.value.override || EMPTY_OVERRIDE);
  });
  return useClientCache("token", computed(() => {
    return [option.value.salt || "", theme.value.id, tokenStr.value, overrideTokenStr.value];
  }), () => {
    const {
      salt = "",
      override = EMPTY_OVERRIDE,
      formatToken
    } = option.value;
    const derivativeToken = theme.value.getDerivativeToken(mergedToken.value);
    let mergedDerivativeToken = {
      ...derivativeToken,
      ...override
    };
    if (formatToken)
      mergedDerivativeToken = formatToken(mergedDerivativeToken);
    const tokenKey = token2key(mergedDerivativeToken, salt);
    mergedDerivativeToken._tokenKey = tokenKey;
    recordCleanToken(tokenKey);
    const hashId = `${hashPrefix}-${hash(tokenKey)}`;
    mergedDerivativeToken._hashId = hashId;
    return [mergedDerivativeToken, hashId];
  }, (cache2) => {
    cleanTokenStyle(cache2[0]._tokenKey, contextProps.cache.instanceId);
  });
}
let warned = {};
function warning(valid, message) {
  if (process.env.NODE_ENV !== "production" && !valid && console !== void 0)
    console.error(`Warning: ${message}`);
}
function call(method, valid, message) {
  if (!valid && !warned[message]) {
    method(false, message);
    warned[message] = true;
  }
}
function warningOnce(valid, message) {
  call(warning, valid, message);
}
function lintWarning(message, info) {
  const { path, parentSelectors } = info;
  warningOnce(
    false,
    `[Ant Design CSS-in-JS] ${path ? `Error in ${path}: ` : ""}${message}${parentSelectors.length ? ` Selector: ${parentSelectors.join(" | ")}` : ""}`
  );
}
const linter$4 = (key, value, info) => {
  if (key === "content") {
    const contentValuePattern = /(attr|counters?|url|(((repeating-)?(linear|radial))|conic)-gradient)\(|(no-)?(open|close)-quote/;
    const contentValues = ["normal", "none", "initial", "inherit", "unset"];
    if (typeof value !== "string" || !contentValues.includes(value) && !contentValuePattern.test(value) && (value.charAt(0) !== value.charAt(value.length - 1) || value.charAt(0) !== '"' && value.charAt(0) !== "'")) {
      lintWarning(
        `You seem to be using a value for 'content' without quotes, try replacing it with \`content: '"${value}"'\`.`,
        info
      );
    }
  }
};
const linter$3 = (key, value, info) => {
  if (key === "animation") {
    if (info.hashId && value !== "none") {
      lintWarning(
        `You seem to be using hashed animation '${value}', in which case 'animationName' with Keyframe as value is recommended.`,
        info
      );
    }
  }
};
function isConcatSelector(selector) {
  var _a;
  const notContent = ((_a = selector.match(/:not\(([^)]*)\)/)) == null ? void 0 : _a[1]) || "";
  const splitCells = notContent.split(/(\[[^[]*])|(?=[.#])/).filter((str) => str);
  return splitCells.length > 1;
}
function parsePath(info) {
  return info.parentSelectors.reduce((prev, cur) => {
    if (!prev)
      return cur;
    return cur.includes("&") ? cur.replace(/&/g, prev) : `${prev} ${cur}`;
  }, "");
}
const linter$2 = (key, value, info) => {
  const parentSelectorPath = parsePath(info);
  const notList = parentSelectorPath.match(/:not\([^)]*\)/g) || [];
  if (notList.length > 0 && notList.some(isConcatSelector))
    lintWarning("Concat ':not' selector not support in legacy browsers.", info);
};
const linter$1 = (key, value, info) => {
  switch (key) {
    case "marginLeft":
    case "marginRight":
    case "paddingLeft":
    case "paddingRight":
    case "left":
    case "right":
    case "borderLeft":
    case "borderLeftWidth":
    case "borderLeftStyle":
    case "borderLeftColor":
    case "borderRight":
    case "borderRightWidth":
    case "borderRightStyle":
    case "borderRightColor":
    case "borderTopLeftRadius":
    case "borderTopRightRadius":
    case "borderBottomLeftRadius":
    case "borderBottomRightRadius":
      lintWarning(
        `You seem to be using non-logical property '${key}' which is not compatible with RTL mode. Please use logical properties and values instead. For more information: https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Logical_Properties.`,
        info
      );
      return;
    case "margin":
    case "padding":
    case "borderWidth":
    case "borderStyle":
      if (typeof value === "string") {
        const valueArr = value.split(" ").map((item) => item.trim());
        if (valueArr.length === 4 && valueArr[1] !== valueArr[3]) {
          lintWarning(
            `You seem to be using '${key}' property with different left ${key} and right ${key}, which is not compatible with RTL mode. Please use logical properties and values instead. For more information: https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Logical_Properties.`,
            info
          );
        }
      }
      return;
    case "clear":
    case "textAlign":
      if (value === "left" || value === "right") {
        lintWarning(
          `You seem to be using non-logical value '${value}' of ${key}, which is not compatible with RTL mode. Please use logical properties and values instead. For more information: https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Logical_Properties.`,
          info
        );
      }
      return;
    case "borderRadius":
      if (typeof value === "string") {
        const radiusGroups = value.split("/").map((item) => item.trim());
        const invalid = radiusGroups.reduce((result, group) => {
          if (result)
            return result;
          const radiusArr = group.split(" ").map((item) => item.trim());
          if (radiusArr.length >= 2 && radiusArr[0] !== radiusArr[1])
            return true;
          if (radiusArr.length === 3 && radiusArr[1] !== radiusArr[2])
            return true;
          if (radiusArr.length === 4 && radiusArr[2] !== radiusArr[3])
            return true;
          return result;
        }, false);
        if (invalid) {
          lintWarning(
            `You seem to be using non-logical value '${value}' of ${key}, which is not compatible with RTL mode. Please use logical properties and values instead. For more information: https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Logical_Properties.`,
            info
          );
        }
      }
  }
};
const linter = (key, value, info) => {
  if (info.parentSelectors.some((selector) => {
    const selectors = selector.split(",");
    return selectors.some((item) => item.split("&").length > 2);
  }))
    lintWarning("Should not use more than one `&` in a selector.", info);
};
const isClientSide = canUseDom();
const SKIP_CHECK = "_skip_check_";
const MULTI_VALUE = "_multi_value_";
function normalizeStyle(styleStr) {
  const serialized = serialize(compile(styleStr), stringify);
  return serialized.replace(/\{%%%\:[^;];}/g, ";");
}
function isCompoundCSSProperty(value) {
  return typeof value === "object" && value && (SKIP_CHECK in value || MULTI_VALUE in value);
}
function injectSelectorHash(key, hashId, hashPriority) {
  if (!hashId)
    return key;
  const hashClassName = `.${hashId}`;
  const hashSelector = hashPriority === "low" ? `:where(${hashClassName})` : hashClassName;
  const keys = key.split(",").map((k) => {
    var _a;
    const fullPath = k.trim().split(/\s+/);
    let firstPath = fullPath[0] || "";
    const htmlElement = ((_a = firstPath.match(/^\w+/)) == null ? void 0 : _a[0]) || "";
    firstPath = `${htmlElement}${hashSelector}${firstPath.slice(htmlElement.length)}`;
    return [firstPath, ...fullPath.slice(1)].join(" ");
  });
  return keys.join(",");
}
const globalEffectStyleKeys = /* @__PURE__ */ new Set();
process.env.NODE_ENV !== "production" ? () => globalEffectStyleKeys.clear() : void 0;
const parseStyle = (interpolation, config = {}, {
  root,
  injectHash,
  parentSelectors
} = {
  root: true,
  parentSelectors: []
}) => {
  const {
    hashId,
    layer,
    path,
    hashPriority,
    transformers = [],
    linters = []
  } = config;
  let styleStr = "";
  let effectStyle = {};
  function parseKeyframes(keyframes) {
    const animationName = keyframes.getName(hashId);
    if (!effectStyle[animationName]) {
      const [parsedStr] = parseStyle(keyframes.style, config, {
        root: false,
        parentSelectors
      });
      effectStyle[animationName] = `@keyframes ${keyframes.getName(hashId)}${parsedStr}`;
    }
  }
  function flattenList(list, fullList = []) {
    list.forEach((item) => {
      if (Array.isArray(item))
        flattenList(item, fullList);
      else if (item)
        fullList.push(item);
    });
    return fullList;
  }
  const flattenStyleList = flattenList(Array.isArray(interpolation) ? interpolation : [interpolation]);
  flattenStyleList.forEach((originStyle) => {
    const style = typeof originStyle === "string" && !root ? {} : originStyle;
    if (typeof style === "string") {
      styleStr += `${style}
`;
    } else if (style._keyframe) {
      parseKeyframes(style);
    } else {
      const mergedStyle = transformers.reduce((prev, trans) => {
        var _a;
        return ((_a = trans == null ? void 0 : trans.visit) == null ? void 0 : _a.call(trans, prev)) || prev;
      }, style);
      Object.keys(mergedStyle).forEach((key) => {
        const value = mergedStyle[key];
        if (typeof value === "object" && value && (key !== "animationName" || !value._keyframe) && !isCompoundCSSProperty(value)) {
          let subInjectHash = false;
          let mergedKey = key.trim();
          let nextRoot = false;
          if ((root || injectHash) && hashId) {
            if (mergedKey.startsWith("@")) {
              subInjectHash = true;
            } else {
              mergedKey = injectSelectorHash(key, hashId, hashPriority);
            }
          } else if (root && !hashId && (mergedKey === "&" || mergedKey === "")) {
            mergedKey = "";
            nextRoot = true;
          }
          const [parsedStr, childEffectStyle] = parseStyle(value, config, {
            root: nextRoot,
            injectHash: subInjectHash,
            parentSelectors: [...parentSelectors, mergedKey]
          });
          effectStyle = {
            ...effectStyle,
            ...childEffectStyle
          };
          styleStr += `${mergedKey}${parsedStr}`;
        } else {
          let appendStyle = function(cssKey, cssValue) {
            if (process.env.NODE_ENV !== "production" && (typeof value !== "object" || !(value == null ? void 0 : value[SKIP_CHECK]))) {
              [linter$4, linter$3, ...linters].forEach((linter2) => linter2(cssKey, cssValue, {
                path,
                hashId,
                parentSelectors
              }));
            }
            const styleName = cssKey.replace(/[A-Z]/g, (match) => `-${match.toLowerCase()}`);
            let formatValue = cssValue;
            if (!unitless[cssKey] && typeof formatValue === "number" && formatValue !== 0)
              formatValue = `${formatValue}px`;
            if (cssKey === "animationName" && (cssValue == null ? void 0 : cssValue._keyframe)) {
              parseKeyframes(cssValue);
              formatValue = cssValue.getName(hashId);
            }
            styleStr += `${styleName}:${formatValue};`;
          };
          const actualValue = (value == null ? void 0 : value.value) ?? value;
          if (typeof value === "object" && (value == null ? void 0 : value[MULTI_VALUE]) && Array.isArray(actualValue)) {
            actualValue.forEach((item) => {
              appendStyle(key, item);
            });
          } else {
            appendStyle(key, actualValue);
          }
        }
      });
    }
  });
  if (!root) {
    styleStr = `{${styleStr}}`;
  } else if (layer && supportLayer()) {
    const layerCells = layer.split(",");
    const layerName = layerCells[layerCells.length - 1].trim();
    styleStr = `@layer ${layerName} {${styleStr}}`;
    if (layerCells.length > 1) {
      styleStr = `@layer ${layer}{%%%:%}${styleStr}`;
    }
  }
  return [styleStr, effectStyle];
};
function uniqueHash(path, styleStr) {
  return hash(`${path.join("%")}${styleStr}`);
}
function Empty() {
  return null;
}
function useStyleRegister(info, styleFn, opt) {
  const styleContext = useStyleInject();
  const tokenKey = computed(() => info.value.token._tokenKey);
  const fullPath = computed(() => [tokenKey.value, ...info.value.path]);
  let isMergedClientSide = isClientSide;
  if (process.env.NODE_ENV !== "production" && styleContext.mock !== void 0)
    isMergedClientSide = styleContext.mock === "client";
  const cacheStyle = useClientCache(
    "style",
    fullPath,
    // Create cache if needed
    () => {
      const styleObj = styleFn();
      const {
        hashPriority,
        container,
        transformers,
        linters
      } = styleContext;
      const {
        path,
        hashId,
        layer,
        nonce
      } = info.value;
      const [parsedStyle, effectStyle] = parseStyle(styleObj, {
        hashId,
        hashPriority,
        layer,
        path: path.join("-"),
        transformers,
        linters
      });
      const styleStr = normalizeStyle(parsedStyle);
      const styleId = uniqueHash(fullPath.value, styleStr);
      if (isMergedClientSide) {
        const mergedCSSConfig = {
          mark: ATTR_MARK,
          prepend: "queue",
          attachTo: container
        };
        const nonceStr = typeof nonce === "function" ? nonce() : nonce;
        if (nonceStr)
          mergedCSSConfig.csp = {
            nonce: nonceStr
          };
        const style = updateCSS(styleStr, styleId, mergedCSSConfig);
        style[CSS_IN_JS_INSTANCE] = styleContext.cache.instanceId;
        style.setAttribute(ATTR_TOKEN, tokenKey.value);
        if (process.env.NODE_ENV !== "production")
          style.setAttribute(ATTR_DEV_CACHE_PATH, fullPath.value.join("|"));
        Object.keys(effectStyle).forEach((effectKey) => {
          if (!globalEffectStyleKeys.has(effectKey)) {
            globalEffectStyleKeys.add(effectKey);
            updateCSS(normalizeStyle(effectStyle[effectKey]), `_effect-${effectKey}`, mergedCSSConfig);
          }
        });
      }
      return [styleStr, tokenKey.value, styleId];
    },
    // Remove cache if no need
    ([, , styleId], fromHMR) => {
      if ((fromHMR || styleContext.autoClear) && isClientSide)
        removeCSS(styleId, {
          mark: ATTR_MARK
        });
    }
  );
  if ((opt == null ? void 0 : opt.sfc) === true) {
    return /* @__PURE__ */ defineComponent({
      name: "StyleRegister",
      inheritAttrs: false,
      setup(_, {
        slots
      }) {
        return () => {
          var _a;
          let styleNode;
          if (!styleContext.ssrInline || isMergedClientSide || !styleContext.defaultCache) {
            styleNode = createVNode(Empty, null, null);
          } else {
            styleNode = createVNode("style", mergeProps({
              [ATTR_TOKEN]: cacheStyle.value[1],
              [ATTR_MARK]: cacheStyle.value[2]
            }, {
              "innerHTML": cacheStyle.value[0]
            }), null);
          }
          return createVNode(Fragment, null, [styleNode, (_a = slots.default) == null ? void 0 : _a.call(slots)]);
        };
      }
    });
  }
  return (node) => {
    let styleNode;
    if (!styleContext.ssrInline || isMergedClientSide || !styleContext.defaultCache) {
      styleNode = createVNode(Empty, null, null);
    } else {
      styleNode = createVNode("style", mergeProps({
        [ATTR_TOKEN]: cacheStyle.value[1],
        [ATTR_MARK]: cacheStyle.value[2]
      }, {
        "innerHTML": cacheStyle.value[0]
      }), null);
    }
    return createVNode(Fragment, null, [styleNode, node]);
  };
}
function extractStyle(cache2, plain = false) {
  const styleKeys = Array.from(cache2.cache.keys()).filter((key) => key.startsWith("style%"));
  let styleText = "";
  styleKeys.forEach((key) => {
    const [styleStr, tokenKey, styleId] = cache2.cache.get(key)[1];
    styleText += plain ? styleStr : `<style ${ATTR_TOKEN}="${tokenKey}" ${ATTR_MARK}="${styleId}">${styleStr}</style>`;
  });
  return styleText;
}
class Keyframe {
  constructor(name, style) {
    __publicField(this, "name");
    __publicField(this, "style");
    __publicField(this, "_keyframe", true);
    this.name = name;
    this.style = style;
  }
  getName(hashId = "") {
    return hashId ? `${hashId}-${this.name}` : this.name;
  }
}
function sameDerivativeOption(left, right) {
  if (left.length !== right.length)
    return false;
  for (let i = 0; i < left.length; i++) {
    if (left[i] !== right[i])
      return false;
  }
  return true;
}
const _ThemeCache = class {
  constructor() {
    __publicField(this, "cache");
    __publicField(this, "keys");
    __publicField(this, "cacheCallTimes");
    this.cache = /* @__PURE__ */ new Map();
    this.keys = [];
    this.cacheCallTimes = 0;
  }
  size() {
    return this.keys.length;
  }
  internalGet(derivativeOption, updateCallTimes = false) {
    let cache2 = { map: this.cache };
    derivativeOption.forEach((derivative) => {
      var _a;
      if (!cache2)
        cache2 = void 0;
      else
        cache2 = (_a = cache2 == null ? void 0 : cache2.map) == null ? void 0 : _a.get(derivative);
    });
    if ((cache2 == null ? void 0 : cache2.value) && updateCallTimes)
      cache2.value[1] = this.cacheCallTimes++;
    return cache2 == null ? void 0 : cache2.value;
  }
  get(derivativeOption) {
    var _a;
    return (_a = this.internalGet(derivativeOption, true)) == null ? void 0 : _a[0];
  }
  has(derivativeOption) {
    return !!this.internalGet(derivativeOption);
  }
  set(derivativeOption, value) {
    if (!this.has(derivativeOption)) {
      if (this.size() + 1 > _ThemeCache.MAX_CACHE_SIZE + _ThemeCache.MAX_CACHE_OFFSET) {
        const [targetKey] = this.keys.reduce(
          (result, key) => {
            const [, callTimes] = result;
            if (this.internalGet(key)[1] < callTimes)
              return [key, this.internalGet(key)[1]];
            return result;
          },
          [this.keys[0], this.cacheCallTimes]
        );
        this.delete(targetKey);
      }
      this.keys.push(derivativeOption);
    }
    let cache2 = this.cache;
    derivativeOption.forEach((derivative, index) => {
      if (index === derivativeOption.length - 1) {
        cache2.set(derivative, { value: [value, this.cacheCallTimes++] });
      } else {
        const cacheValue = cache2.get(derivative);
        if (!cacheValue)
          cache2.set(derivative, { map: /* @__PURE__ */ new Map() });
        else if (!cacheValue.map)
          cacheValue.map = /* @__PURE__ */ new Map();
        cache2 = cache2.get(derivative).map;
      }
    });
  }
  deleteByPath(currentCache, derivatives) {
    var _a;
    const cache2 = currentCache.get(derivatives[0]);
    if (derivatives.length === 1) {
      if (!cache2.map)
        currentCache.delete(derivatives[0]);
      else
        currentCache.set(derivatives[0], { map: cache2.map });
      return (_a = cache2.value) == null ? void 0 : _a[0];
    }
    const result = this.deleteByPath(cache2.map, derivatives.slice(1));
    if ((!cache2.map || cache2.map.size === 0) && !cache2.value)
      currentCache.delete(derivatives[0]);
    return result;
  }
  delete(derivativeOption) {
    if (this.has(derivativeOption)) {
      this.keys = this.keys.filter(
        (item) => !sameDerivativeOption(item, derivativeOption)
      );
      return this.deleteByPath(this.cache, derivativeOption);
    }
    return void 0;
  }
};
let ThemeCache = _ThemeCache;
__publicField(ThemeCache, "MAX_CACHE_SIZE", 20);
__publicField(ThemeCache, "MAX_CACHE_OFFSET", 5);
let uuid = 0;
class Theme {
  constructor(derivatives) {
    __publicField(this, "derivatives");
    __publicField(this, "id");
    this.derivatives = Array.isArray(derivatives) ? derivatives : [derivatives];
    this.id = uuid;
    if (derivatives.length === 0) {
      warning(
        derivatives.length > 0,
        "[Ant Design CSS-in-JS] Theme should have at least one derivative function."
      );
    }
    uuid += 1;
  }
  getDerivativeToken(token) {
    return this.derivatives.reduce(
      (result, derivative) => derivative(token, result),
      void 0
    );
  }
}
const cacheThemes = new ThemeCache();
function createTheme(derivatives) {
  const derivativeArr = Array.isArray(derivatives) ? derivatives : [derivatives];
  if (!cacheThemes.has(derivativeArr))
    cacheThemes.set(derivativeArr, new Theme(derivativeArr));
  return cacheThemes.get(derivativeArr);
}
function splitValues(value) {
  if (typeof value === "number")
    return [[value], false];
  const rawStyle = String(value).trim();
  const importantCells = rawStyle.match(/(.*)(!important)/);
  const splitStyle = (importantCells ? importantCells[1] : rawStyle).trim().split(/\s+/);
  let temp = "";
  let brackets = 0;
  return [
    splitStyle.reduce((list, item) => {
      if (item.includes("(")) {
        temp += item;
        brackets += item.split("(").length - 1;
      } else if (item.includes(")")) {
        temp += ` ${item}`;
        brackets -= item.split(")").length - 1;
        if (brackets === 0) {
          list.push(temp);
          temp = "";
        }
      } else if (brackets > 0) {
        temp += ` ${item}`;
      } else {
        list.push(item);
      }
      return list;
    }, []),
    !!importantCells
  ];
}
function noSplit(list) {
  list.notSplit = true;
  return list;
}
const keyMap = {
  // Inset
  inset: ["top", "right", "bottom", "left"],
  insetBlock: ["top", "bottom"],
  insetBlockStart: ["top"],
  insetBlockEnd: ["bottom"],
  insetInline: ["left", "right"],
  insetInlineStart: ["left"],
  insetInlineEnd: ["right"],
  // Margin
  marginBlock: ["marginTop", "marginBottom"],
  marginBlockStart: ["marginTop"],
  marginBlockEnd: ["marginBottom"],
  marginInline: ["marginLeft", "marginRight"],
  marginInlineStart: ["marginLeft"],
  marginInlineEnd: ["marginRight"],
  // Padding
  paddingBlock: ["paddingTop", "paddingBottom"],
  paddingBlockStart: ["paddingTop"],
  paddingBlockEnd: ["paddingBottom"],
  paddingInline: ["paddingLeft", "paddingRight"],
  paddingInlineStart: ["paddingLeft"],
  paddingInlineEnd: ["paddingRight"],
  // Border
  borderBlock: noSplit(["borderTop", "borderBottom"]),
  borderBlockStart: noSplit(["borderTop"]),
  borderBlockEnd: noSplit(["borderBottom"]),
  borderInline: noSplit(["borderLeft", "borderRight"]),
  borderInlineStart: noSplit(["borderLeft"]),
  borderInlineEnd: noSplit(["borderRight"]),
  // Border width
  borderBlockWidth: ["borderTopWidth", "borderBottomWidth"],
  borderBlockStartWidth: ["borderTopWidth"],
  borderBlockEndWidth: ["borderBottomWidth"],
  borderInlineWidth: ["borderLeftWidth", "borderRightWidth"],
  borderInlineStartWidth: ["borderLeftWidth"],
  borderInlineEndWidth: ["borderRightWidth"],
  // Border style
  borderBlockStyle: ["borderTopStyle", "borderBottomStyle"],
  borderBlockStartStyle: ["borderTopStyle"],
  borderBlockEndStyle: ["borderBottomStyle"],
  borderInlineStyle: ["borderLeftStyle", "borderRightStyle"],
  borderInlineStartStyle: ["borderLeftStyle"],
  borderInlineEndStyle: ["borderRightStyle"],
  // Border color
  borderBlockColor: ["borderTopColor", "borderBottomColor"],
  borderBlockStartColor: ["borderTopColor"],
  borderBlockEndColor: ["borderBottomColor"],
  borderInlineColor: ["borderLeftColor", "borderRightColor"],
  borderInlineStartColor: ["borderLeftColor"],
  borderInlineEndColor: ["borderRightColor"],
  // Border radius
  borderStartStartRadius: ["borderTopLeftRadius"],
  borderStartEndRadius: ["borderTopRightRadius"],
  borderEndStartRadius: ["borderBottomLeftRadius"],
  borderEndEndRadius: ["borderBottomRightRadius"]
};
function wrapImportantAndSkipCheck(value, important) {
  let parsedValue = value;
  if (important)
    parsedValue = `${parsedValue} !important`;
  return { _skip_check_: true, value: parsedValue };
}
const transform$1 = {
  visit: (cssObj) => {
    const clone = {};
    Object.keys(cssObj).forEach((key) => {
      const value = cssObj[key];
      const matchValue = keyMap[key];
      if (matchValue && (typeof value === "number" || typeof value === "string")) {
        const [values, important] = splitValues(value);
        if (matchValue.length && matchValue.notSplit) {
          matchValue.forEach((matchKey) => {
            clone[matchKey] = wrapImportantAndSkipCheck(value, important);
          });
        } else if (matchValue.length === 1) {
          clone[matchValue[0]] = wrapImportantAndSkipCheck(value, important);
        } else if (matchValue.length === 2) {
          matchValue.forEach((matchKey, index) => {
            clone[matchKey] = wrapImportantAndSkipCheck(
              values[index] ?? values[0],
              important
            );
          });
        } else if (matchValue.length === 4) {
          matchValue.forEach((matchKey, index) => {
            clone[matchKey] = wrapImportantAndSkipCheck(
              values[index] ?? values[index - 2] ?? values[0],
              important
            );
          });
        } else {
          clone[key] = value;
        }
      } else {
        clone[key] = value;
      }
    });
    return clone;
  }
};
const pxRegex = /url\([^)]+\)|var\([^)]+\)|(\d*\.?\d+)px/g;
function toFixed(number, precision) {
  const multiplier = Math.pow(10, precision + 1);
  const wholeNumber = Math.floor(number * multiplier);
  return Math.round(wholeNumber / 10) * 10 / multiplier;
}
const transform = (options = {}) => {
  const { rootValue = 16, precision = 5, mediaQuery = false } = options;
  const pxReplace = (m, $1) => {
    if (!$1)
      return m;
    const pixels = parseFloat($1);
    if (pixels <= 1)
      return m;
    const fixedVal = toFixed(pixels / rootValue, precision);
    return `${fixedVal}rem`;
  };
  const visit = (cssObj) => {
    const clone = { ...cssObj };
    Object.entries(cssObj).forEach(([key, value]) => {
      if (typeof value === "string" && value.includes("px")) {
        const newValue = value.replace(pxRegex, pxReplace);
        clone[key] = newValue;
      }
      if (!unitless[key] && typeof value === "number" && value !== 0)
        clone[key] = `${value}px`.replace(pxRegex, pxReplace);
      const mergedKey = key.trim();
      if (mergedKey.startsWith("@") && mergedKey.includes("px") && mediaQuery) {
        const newKey = key.replace(pxRegex, pxReplace);
        clone[newKey] = clone[key];
        delete clone[key];
      }
    });
    return clone;
  };
  return { visit };
};
export {
  Keyframe as Keyframes,
  StyleProvider,
  Theme,
  createCache,
  createTheme,
  extractStyle,
  transform$1 as legacyLogicalPropertiesTransformer,
  linter$2 as legacyNotSelectorLinter,
  linter$1 as logicalPropertiesLinter,
  linter as parentSelectorLinter,
  transform as px2remTransformer,
  useCacheToken,
  useStyleInject,
  useStyleProvider,
  useStyleRegister
};
